@@ -25,15 +25,16 @@ class AbilianCsrf(object):
     #: users.
     csrf_failed_message = _l(
         'Security informations are missing or expired. '
-        'This may happen if you have opened the form for a long time. <br /><br />'
+        'This may happen if you have opened the form for a long time. '
+        '<br /><br />'
         'Please try to resubmit the form.',
     )
 
     def init_app(self, app):
         if 'csrf' not in app.extensions:
             raise RuntimeError(
-                'Please install flask_wtf.csrf.CsrfProtect() as "csrf" in extensions'
-                ' before AbilianCsrf()',
+                'Please install flask_wtf.csrf.CsrfProtect() as "csrf" in '
+                'extensions before AbilianCsrf()',
             )
         app.extensions['csrf'].error_handler(self.csrf_error_handler)
         app.extensions['csrf-handler'] = self
