@@ -45,9 +45,11 @@ def register(cls):
     return cls
 
 
-def is_support_attachments(obj):
+def supports_attachments(obj):
     """
     :param obj: a class or instance
+
+    :returns: True is obj supports attachments.
     """
     if isinstance(obj, type):
         return issubclass(obj, SupportAttachment)
@@ -63,7 +65,7 @@ def is_support_attachments(obj):
 
 def for_entity(obj, check_support_attachments=False):
     """Return attachments on an entity."""
-    if check_support_attachments and not is_support_attachments(obj):
+    if check_support_attachments and not supports_attachments(obj):
         return []
 
     return getattr(obj, ATTRIBUTE)
@@ -75,9 +77,10 @@ class Attachment(Entity):
 
     @sa.ext.declarative.declared_attr
     def __mapper_args__(cls):
-        # we cannot use super(Attachment, cls): declared_attr happens during class
-        # construction. super(cls, cls) could work; as long as `cls` is not a
-        # subclass of `Attachment`: it would enter into an infinite loop.
+        # we cannot use super(Attachment, cls): declared_attr happens during
+        # class construction. super(cls, cls) could work; as long as `cls`
+        # is not a subclass of `Attachment`: it would enter into
+        # an infinite loop.
         #
         # Entity.__mapper_args__ calls the descriptor with 'Entity', not `cls`.
         args = Entity.__dict__['__mapper_args__'].fget(cls)
@@ -114,7 +117,7 @@ class Attachment(Entity):
         class_ = self.__class__
         mod_ = class_.__module__
         classname = class_.__name__
-        return '<{}.{} instance at 0x{:x} entity id={!r}'\
+        return '<{}.{} instance at 0x{:x} entity id={!r}>' \
             .format(mod_, classname, id(self), self.entity_id)
 
 
