@@ -59,18 +59,7 @@ class Indexable(object):
     __indexation_args__ = {
         'index_to': (
             ('object_key', (('object_key', ID(stored=True, unique=True)),)),
-            (
-                'object_type',
-                (
-                    (
-                        'object_type',
-                        ID(
-                            stored=True,
-                            unique=False,
-                        ),
-                    ),
-                ),
-            ),
+            ('object_type', (('object_type', ID(stored=True, unique=False)),)),
         ),
     }
 
