@@ -1,6 +1,5 @@
 # coding=utf-8
-""" Additional data types for sqlalchemy
-"""
+"""Additional data types for sqlalchemy."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -10,9 +9,14 @@ import sys
 import uuid
 
 import babel
+import babel.dates
 import flask_sqlalchemy as flask_sa
 import pytz
 import sqlalchemy as sa
+import sqlalchemy.dialects
+import sqlalchemy.exc
+import sqlalchemy.orm
+import sqlalchemy.pool
 from flask_sqlalchemy import SQLAlchemy as SAExtension
 from six import string_types, text_type
 from sqlalchemy.event import listens_for
@@ -34,7 +38,7 @@ def ping_connection(dbapi_connection, connection_record, connection_proxy):
     cursor = dbapi_connection.cursor()
     try:
         cursor.execute("SELECT 1")
-    except:
+    except BaseException:
         # optional - dispose the whole pool
         # instead of invalidating one at a time
         # connection_proxy._pool.dispose()
@@ -75,8 +79,10 @@ def _calling_context(app_path):
     frm = sys._getframe(1)
     entered_sa_code = exited_sa_code = False
     sa_caller = '<unknown>'
-    format_name = ('{frm.f_code.co_filename}:{frm.f_lineno} '
-                   '({frm.f_code.co_name})'.format)
+    format_name = (
+        '{frm.f_code.co_filename}:{frm.f_lineno} '
+        '({frm.f_code.co_name})'.format
+    )
 
     while frm.f_back is not None:
         name = frm.f_globals.get('__name__')
@@ -113,8 +119,10 @@ def filter_cols(model, *filtered_columns):
     """
     m = sa.orm.class_mapper(model)
     return list(
-        set(p.key for p in m.iterate_properties
-            if hasattr(p, 'columns')).difference(filtered_columns))
+        {p.key
+         for p in m.iterate_properties
+         if hasattr(p, 'columns')}.difference(filtered_columns),
+    )
 
 
 class MutationDict(Mutable, dict):
@@ -174,9 +182,7 @@ class MutationDict(Mutable, dict):
 
 
 class MutationList(Mutable, list):
-    """
-    Provides a list type with mutability support.
-    """
+    """Provides a list type with mutability support."""
 
     @classmethod
     def coerce(cls, key, value):
@@ -210,13 +216,13 @@ class MutationList(Mutable, list):
         list.insert(self, idx, value)
         self.changed()
 
-    def __setslice__(self, i, j, other):
-        list.__setslice__(self, i, j, other)
-        self.changed()
-
-    def __delslice__(self, i, j):
-        list.__delslice__(self, i, j)
-        self.changed()
+    # def __setslice__(self, i, j, other):
+    #     list.__setslice__(self, i, j, other)
+    #     self.changed()
+    #
+    # def __delslice__(self, i, j):
+    #     list.__delslice__(self, i, j)
+    #     self.changed()
 
     def __iadd__(self, other):
         l = list.__iadd__(self, other)
@@ -257,9 +263,7 @@ class MutationList(Mutable, list):
 class JSON(sa.types.TypeDecorator):
     """Stores any structure serializable with json.
 
-    Usage
-    JSON()
-    Takes same parameters as sqlalchemy.types.Text
+    Usage JSON() Takes same parameters as sqlalchemy.types.Text
     """
     impl = sa.types.Text
 
@@ -275,8 +279,7 @@ class JSON(sa.types.TypeDecorator):
 
 
 class JSONUniqueListType(JSON):
-    """Store a list in JSON format, with items made unique and sorted.
-    """
+    """Store a list in JSON format, with items made unique and sorted."""
 
     @property
     def python_type(self):
@@ -292,16 +295,15 @@ class JSONUniqueListType(JSON):
 
 
 def JSONDict(*args, **kwargs):
-    """Stores a dict as JSON on database, with mutability support.
-    """
+    """Stores a dict as JSON on database, with mutability support."""
     return MutationDict.as_mutable(JSON(*args, **kwargs))
 
 
 def JSONList(*args, **kwargs):
     """Stores a list as JSON on database, with mutability support.
 
-    If kwargs has a param `unique_sorted` (which evaluated to True), list values
-    are made unique and sorted.
+    If kwargs has a param `unique_sorted` (which evaluated to True),
+    list values are made unique and sorted.
     """
     type_ = JSON
     try:
@@ -351,8 +353,7 @@ class UUID(sa.types.TypeDecorator):
 
 
 class Locale(sa.types.TypeDecorator):
-    """Store a :class:`babel.Locale` instance
-    """
+    """Store a :class:`babel.Locale` instance."""
     impl = sa.types.UnicodeText
 
     @property
@@ -365,16 +366,19 @@ class Locale(sa.types.TypeDecorator):
 
         if not isinstance(value, babel.Locale):
             if not isinstance(value, string_types):
-                raise ValueError("Unknown locale value: %s" % repr(value))
+                raise ValueError(
+                    "Unknown locale value: " +
+                    format(
+                        repr(value)))
             if not value.strip():
                 return None
             value = babel.Locale.parse(value)
 
         code = text_type(value.language)
         if value.territory:
-            code += u'_' + text_type(value.territory)
+            code += '_' + text_type(value.territory)
         elif value.script:
-            code += u'_' + text_type(value.territory)
+            code += '_' + text_type(value.territory)
 
         return code
 
@@ -383,8 +387,7 @@ class Locale(sa.types.TypeDecorator):
 
 
 class Timezone(sa.types.TypeDecorator):
-    """Store a :class:`pytz.tzfile.DstTzInfo` instance
-    """
+    """Store a :class:`pytz.tzfile.DstTzInfo` instance."""
     impl = sa.types.UnicodeText
 
     @property
@@ -397,7 +400,7 @@ class Timezone(sa.types.TypeDecorator):
 
         if not isinstance(value, pytz.tzfile.DstTzInfo):
             if not isinstance(value, string_types):
-                raise ValueError("Unknown timezone value: %s" % repr(value))
+                raise ValueError("Unknown timezone value: " + repr(value))
             if not value.strip():
                 return None
             value = babel.dates.get_timezone(value)
@@ -413,6 +416,7 @@ class Timezone(sa.types.TypeDecorator):
 # those symbols in documentation, and this may break since we don't have
 # sphinx's extensions used by sqlalchemy author.
 #
-# Ref: https://bitbucket.org/zzzeek/sqlalchemy/issues/3218/__module__-should-be-set-on-functions
+# Ref:
+# https://bitbucket.org/zzzeek/sqlalchemy/issues/3218/__module__-should-be-set-on-functions
 if not sa.orm.relationship.__module__:
     sa.orm.relationship.__module__ = 'sqlalchemy.orm'
