@@ -119,12 +119,12 @@ class AuthService(Service):
             user = User.query.get(user_id)
 
             if not user or not user.can_login:
-                # if a user is edited and should not have access any more, this will
-                # ensure he cannot continue if he had an active session
+                # if a user is edited and should not have access any more, this
+                # will ensure they cannot continue if he had an active session
                 return None
         except BaseException:
             logger.warning("Error during login.", exc_info=True)
-            session = current_app.db.session()
+            session = db.session()
             if not session.is_active:
                 # session is not usable, rollback should restore a usable
                 # session
@@ -172,7 +172,7 @@ class AuthService(Service):
         if current_app.testing and current_app.config.get("NO_LOGIN"):
             # Special case for tests
             user = User.query.get(0)
-            login_user(user, False, True)
+            login_user(user, force=True)
             return
 
         state = self.app_state
@@ -211,8 +211,8 @@ class AuthService(Service):
         if current_user.is_anonymous:
             return
 
-        # Update last_active every 60 seconds only so as to not stress the database
-        # too much.
+        # Update last_active every 60 seconds only so as to not stress
+        # the database too much.
         now = datetime.utcnow()
         if (user.last_active is None or
                 (now - user.last_active) > timedelta(minutes=1)):
