@@ -23,7 +23,15 @@ converter.register_handler(PdfToPpmHandler())
 converter.register_handler(ImageMagickHandler())
 converter.register_handler(LibreOfficePdfHandler())
 
-__all__ = ['converter', 'Converter', 'ConversionError', 'HandlerNotFound']
+conversion_service = converter
+
+__all__ = (
+    'conversion_service',
+    'converter',
+    'Converter',
+    'ConversionError',
+    'HandlerNotFound',
+)
 
 # converter.register_handler(AbiwordPDFHandler())
 # converter.register_handler(AbiwordTextHandler())
