@@ -12,6 +12,7 @@ import threading
 import traceback
 from abc import ABCMeta, abstractmethod
 from base64 import decodestring, encodestring
+from pathlib import Path
 from typing import List
 
 from magic import Magic
@@ -276,18 +277,23 @@ class UnoconvPdfHandler(Handler):
         execute_ok = False
 
         if unoconv:
-            found = os.path.isfile(unoconv)
+            unoconv_path = Path(unoconv)
+            found = unoconv_path.is_file()
             if found:
                 # make absolute path: avoid errors when running with different
                 # CWD
                 unoconv = os.path.abspath(unoconv)
                 execute_ok = os.access(unoconv, os.X_OK)
                 if not execute_ok:
-                    self.log.warning('Not allowed to execute "{}", fallback to '
-                                     '"unoconv"'.format(unoconv))
+                    self.log.warning(
+                        'Not allowed to execute "%s", fallback to "unoconv"',
+                        unoconv,
+                    )
             else:
-                self.log.warning('Cannot find "{}", fallback to "unoconv"'
-                                 ''.format(unoconv))
+                self.log.warning(
+                    'Cannot find "%s", fallback to "unoconv"',
+                    unoconv,
+                )
 
         if not unoconv or not found or not execute_ok:
             unoconv = 'unoconv'
@@ -297,9 +303,9 @@ class UnoconvPdfHandler(Handler):
     @property
     def unoconv_version(self):
         # Hack for my Mac, FIXME later
-        if os.path.exists(
-                "/Applications/LibreOffice.app/Contents/program/python",
-        ):
+        if Path(
+            "/Applications/LibreOffice.app/Contents/program/python",
+        ).exists():
             cmd = [
                 '/Applications/LibreOffice.app/Contents/program/python',
                 '/usr/local/bin/unoconv',
@@ -318,21 +324,17 @@ class UnoconvPdfHandler(Handler):
         with make_temp_file(blob) as in_fn, \
                 make_temp_file(prefix='tmp-unoconv-', suffix=".pdf") as out_fn:
 
+            args = ['-f', 'pdf', '-o', out_fn, in_fn]
             # Hack for my Mac, FIXME later
-            if os.path.exists(
-                    "/Applications/LibreOffice.app/Contents/program/python",
-            ):
+            if Path(
+                "/Applications/LibreOffice.app/Contents/program/python",
+            ).exists():
                 cmd = [
                     '/Applications/LibreOffice.app/Contents/program/python',
                     '/usr/local/bin/unoconv',
-                    '-f',
-                    'pdf',
-                    '-o',
-                    out_fn,
-                    in_fn,
-                ]
+                ] + args
             else:
-                cmd = [self.unoconv, '-f', 'pdf', '-o', out_fn, in_fn]
+                cmd = [self.unoconv] + args
 
             def run_uno():
                 try:
@@ -358,9 +360,10 @@ class UnoconvPdfHandler(Handler):
                         try:
                             self._process.kill()
                         except OSError:
-                            logger.warning("Failed to kill process {}".format(
+                            logger.warning(
+                                "Failed to kill process %s",
                                 self._process,
-                            ))
+                            )
 
                     self._process = None
                     raise ConversionError(
@@ -403,15 +406,15 @@ class LibreOfficePdfHandler(Handler):
 
         if soffice:
             # make absolute path: avoid errors when running with different CWD
-            soffice = os.path.abspath(soffice)
-            found = os.path.isfile(soffice)
+            soffice_path = Path(soffice).resolve()
+            found = soffice_path.is_file()
             if not found:
-                self.log.error("Can't find executable {}".format(soffice))
+                self.log.error("Can't find executable %s", soffice)
 
-        elif os.path.isfile("/usr/local/bin/soffice"):
+        elif Path("/usr/local/bin/soffice").is_file():
             soffice = "/usr/local/bin/soffice"
 
-        elif os.path.isfile("/usr/bin/soffice"):
+        elif Path("/usr/bin/soffice").is_file():
             soffice = "/usr/bin/soffice"
 
         if soffice:
@@ -464,9 +467,10 @@ class LibreOfficePdfHandler(Handler):
                         try:
                             self._process.kill()
                         except OSError:
-                            logger.warning("Failed to kill process {}".format(
+                            logger.warning(
+                                "Failed to kill process %s",
                                 self._process,
-                            ))
+                            )
 
                     self._process = None
                     raise ConversionError(
