@@ -14,21 +14,22 @@ from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import logging
-import os
 from inspect import isclass
+from pathlib import Path
 
 import sqlalchemy as sa
-import whoosh.index
 import whoosh.query as wq
 from celery import shared_task
 from flask import _app_ctx_stack, appcontext_pushed, current_app, g
 from flask.globals import _lookup_app_object
 from flask_login import current_user
+from six import text_type
 from sqlalchemy import event
 from sqlalchemy.orm.session import Session
 from whoosh.analysis import CharsetFilter, StemmingAnalyzer
 from whoosh.collectors import WrappingCollector
 from whoosh.filedb.filestore import FileStorage, RamStorage
+from whoosh.index import FileIndex
 from whoosh.qparser import DisMaxParser
 from whoosh.support.charset import accent_map
 from whoosh.writing import CLEAR, AsyncWriter
@@ -136,14 +137,15 @@ class WhooshIndexService(Service):
         Service.init_app(self, app)
         state = app.extensions[self.name]
 
-        whoosh_base = app.config.get("WHOOSH_BASE")
-        if not whoosh_base:
-            whoosh_base = "whoosh"  # Default value
+        whoosh_base = Path(app.config.get("WHOOSH_BASE", "whoosh"))
 
-        if not os.path.isabs(whoosh_base):
-            whoosh_base = os.path.join(app.instance_path, whoosh_base)
+        if not whoosh_base.is_absolute():
+            whoosh_base = app.instance_path / whoosh_base
 
-        state.whoosh_base = os.path.abspath(whoosh_base)
+        if not whoosh_base.is_dir():
+            whoosh_base.mkdir(parents=True)
+
+        state.whoosh_base = text_type(whoosh_base.resolve())
 
         if not self._listening:
             event.listen(Session, "after_flush", self.after_flush)
@@ -195,16 +197,16 @@ class WhooshIndexService(Service):
             if current_app.testing:
                 storage = TestingStorage()
             else:
-                index_path = os.path.join(state.whoosh_base, name)
-                if not os.path.exists(index_path):
-                    os.makedirs(index_path)
-                storage = FileStorage(index_path)
+                index_path = (Path(state.whoosh_base) / name).absolute()
+                if not index_path.exists():
+                    index_path.mkdir(parents=True)
+                storage = FileStorage(text_type(index_path))
 
-            FileIndex = whoosh.index.FileIndex
-            if not storage.index_exists(name):
-                FileIndex = whoosh.index.FileIndex.create
+            if storage.index_exists(name):
+                index = FileIndex(storage, schema, name)
+            else:
+                index = FileIndex.create(storage, schema, name)
 
-            index = FileIndex(storage, schema, name)
             state.indexes[name] = index
 
     def clear(self):
