@@ -5,6 +5,7 @@ from __future__ import absolute_import, division, print_function, \
 
 from flask import current_app, g, redirect, render_template, request
 
+from abilian.core.extensions import db
 from abilian.i18n import _, _l
 from abilian.services import get_service
 from abilian.web import url_for, views
@@ -131,7 +132,7 @@ class VocabularyPanel(AdminPanel):
         else:
             return do_return()
 
-        session = current_app.db.session()
+        session = db.session()
         query = Model.query.with_lockmode('update')
         item = query.get(object_id)
         other = query \
@@ -202,19 +203,19 @@ class VocabularyPanel(AdminPanel):
         )
 
     def url_value_preprocess(self, endpoint, view_args):
-        Model = view_args.pop('Model', None)
+        model_name = view_args.pop('Model', None)
         group = view_args.pop('group', _MARKER)
 
         if group == '_':
             # "General" group
-            group = None
+            group = ""
 
         if group is not _MARKER:
             view_args['group'] = group
 
-        if Model is not None:
+        if model_name is not None:
             svc = get_service('vocabularies')
-            Model = svc.get_vocabulary(name=Model, group=group)
+            Model = svc.get_vocabulary(name=model_name, group=group)
             g.breadcrumb.append(BreadcrumbItem(
                 label=Model.Meta.group if group else _('Global'),
                 url=url_for('.vocabularies_group', group=group or '_'),
