@@ -27,7 +27,7 @@ def _grouped_vocabularies():
     return by_group
 
 
-def get_vocabulary(name, group=None):
+def get_vocabulary(name, group=""):
     name = name.lower()
     vocs = _grouped_vocabularies()
     for voc in vocs.get(group, ()):
@@ -52,7 +52,7 @@ class VocabularyService(Service):
     def grouped_vocabularies(self):
         return _grouped_vocabularies()
 
-    def get_vocabulary(self, name, group=None):
+    def get_vocabulary(self, name, group=""):
         return get_vocabulary(name, group=group)
 
 
