@@ -38,15 +38,16 @@ class Admin(object):
         self.breadcrumb_items = {}
         self.setup_blueprint()
 
+        def condition(context):
+            return not current_user.is_anonymous \
+                and security.has_role(current_user, AdminRole)
+
         self.nav_root = NavGroup(
             'admin',
             'root',
             title=_l('Admin'),
             endpoint=None,
-            condition=lambda context: (not current_user.is_anonymous and security.has_role(
-                current_user,
-                AdminRole,
-            )),
+            condition=condition,
         )
 
         for panel in panels:
@@ -134,7 +135,6 @@ class Admin(object):
             nav_id,
             title=panel.label,
             icon=panel.icon,
-            divider=False,
             endpoint=abs_endpoint,
         )
         self.nav_root.append(nav)
