@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -17,11 +16,11 @@ from abilian.web.forms.widgets import TextArea
 class CommentForm(Form):
 
     body = TextAreaField(
-        label=_l(u'Comment'),
+        label=_l('Comment'),
         validators=[required()],
         filters=(strip,),
-        widget=TextArea(
-            rows=5, resizeable='vertical'),)
+        widget=TextArea(rows=5, resizeable='vertical'),
+    )
 
     class Meta:
         model = Comment
