@@ -18,16 +18,17 @@ from flask_babel import format_date, format_datetime, get_locale, get_timezone
 from flask_login import current_user
 from flask_wtf.file import FileField as BaseFileField
 from six import PY2, string_types
+from wtforms import Field
 from wtforms import FieldList as BaseFieldList
 from wtforms import FormField as BaseFormField
-from wtforms import Field, SelectField, SelectFieldBase, SelectMultipleField, \
+from wtforms import SelectField, SelectFieldBase, SelectMultipleField, \
     ValidationError
 from wtforms.compat import text_type
 from wtforms.ext.csrf import SecureForm
 from wtforms.validators import DataRequired, Optional
 from wtforms_alchemy import ModelFieldList as BaseModelFieldList
 from wtforms_alchemy import ModelFormField as BaseModelFormField
-from wtforms_sqlalchemy.fields import get_pk_from_identity, has_identity_key
+from wtforms_sqlalchemy.fields import has_identity_key
 
 from abilian import i18n
 from abilian.core.extensions import db
@@ -40,6 +41,7 @@ __all__ = [
     'ModelFieldList',
     'FileField',
     'DateField',
+    'DateTimeField',
     'Select2Field',
     'Select2MultipleField',
     'QuerySelect2Field',
@@ -411,7 +413,7 @@ class DateField(Field):
             try:
                 strptime = datetime.datetime.strptime
                 self.data = strptime(date_str, date_fmt).date()
-            except ValueError:
+            except (ValueError, TypeError):
                 self.data = None
                 raise ValueError(self.gettext('Not a valid datetime value'))
         else:
@@ -522,7 +524,7 @@ class QuerySelect2Field(SelectFieldBase):
                 raise Exception(
                     'The sqlalchemy identity_key function could not be imported.',
                 )
-            self.get_pk = get_pk_from_identity
+            self.get_pk = self._get_pk_from_identity
         else:
             self.get_pk = get_pk
 
@@ -538,6 +540,16 @@ class QuerySelect2Field(SelectFieldBase):
         self.query = None
         self._object_list = None
 
+    @staticmethod
+    def _get_pk_from_identity(obj):
+        """Copied / pasted, and fixed, from WTForms_sqlalchemy due to issue
+        w/ SQLAlchemy >= 1.2.
+        """
+        from sqlalchemy.orm.util import identity_key
+
+        cls, key = identity_key(instance=obj)[0:2]
+        return ':'.join(text_type(x) for x in key)
+
     def _get_data(self):
         formdata = self._formdata
         if formdata is not None:
