@@ -11,7 +11,6 @@ from wtforms.form import Form
 
 from abilian.core.entities import Entity
 from abilian.services.security import READ, WRITE, Anonymous, Owner, Role
-from abilian.testing import BaseTestCase
 
 from . import FormPermissions, fields, filters
 
@@ -137,108 +136,121 @@ def test_form_permissions_controller():
         assert has_role.call_args[-1]['role'] == [Owner, MarkRole]
 
 
-class FieldsTestCase(BaseTestCase):
+def patch_babel(app):
+    app.extensions['babel'].timezone_selector_func = None
+    app.extensions['babel'].timezoneselector(user_tz)
 
-    def create_app(self):
-        app = super(FieldsTestCase, self).create_app()
-        app.extensions['babel'].timezone_selector_func = None
-        app.extensions['babel'].timezoneselector(user_tz)
-        return app
 
-    def test_datetime_field(self):
-        """Test fields supports date with year < 1900."""
-        obj = mock.Mock()
+def test_datetime_field(app):
+    """Test fields supports date with year < 1900."""
 
-        headers = {'Accept-Language': 'fr-FR,fr;q=0.8'}
-        with self.app.test_request_context(headers=headers):
-            field = fields.DateTimeField(use_naive=False).bind(Form(), 'dt')
-            field.process_formdata(['17/06/1789 | 10:42'])
-            # 1789: applied offset for HongKong is equal to LMT+7:37:00,
-            # thus we compare with tzinfo=user_tz
-            expected_datetime = datetime.datetime(
-                1789,
-                6,
-                17,
-                10,
-                42,
-                tzinfo=USER_TZ,
-            )
-            assert field.data == expected_datetime
-            # UTC stored
-            assert field.data.tzinfo is pytz.UTC
-            # displayed in user current timezone
-            assert field._value() == '17/06/1789 10:42'
+    assert 'fr' in app.config['BABEL_ACCEPT_LANGUAGES']
 
-            # non-naive mode: test process_data change TZ to user's TZ
-            field.process_data(field.data)
-            assert field.data.tzinfo is USER_TZ
-            assert field.data == expected_datetime
+    patch_babel(app)
 
-            field.populate_obj(obj, 'dt')
-            assert obj.dt == expected_datetime
+    obj = mock.Mock()
 
-            # test more recent date: offset is GMT+8
-            field.process_formdata(['23/01/2011 | 10:42'])
-            expected_datetime = datetime.datetime(
-                2011,
-                1,
-                23,
-                2,
-                42,
-                tzinfo=pytz.utc,
-            )
-            assert field.data == expected_datetime
+    headers = {'Accept-Language': 'fr-FR,fr;q=0.8'}
+    with app.test_request_context(headers=headers):
+        field = fields.DateTimeField(use_naive=False).bind(Form(), 'dt')
+        field.process_formdata(['17/06/1789 | 10:42'])
+        # 1789: applied offset for HongKong is equal to LMT+7:37:00,
+        # thus we compare with tzinfo=user_tz
+        expected_datetime = datetime.datetime(
+            1789,
+            6,
+            17,
+            10,
+            42,
+            tzinfo=USER_TZ,
+        )
+        assert field.data == expected_datetime
+        # UTC stored
+        assert field.data.tzinfo is pytz.UTC
+        # displayed in user current timezone
+        assert field._value() == '17/06/1789 10:42'
 
-    def test_datetime_field_naive(self):
-        """Test fields supports date with year < 1900."""
-        obj = mock.Mock()
+        # non-naive mode: test process_data change TZ to user's TZ
+        field.process_data(field.data)
+        assert field.data.tzinfo is USER_TZ
+        assert field.data == expected_datetime
 
-        headers = {'Accept-Language': 'fr-FR,fr;q=0.8'}
-        with self.app.test_request_context(headers=headers):
-            # NAIVE mode: dates without timezone. Those are the problematic ones when
-            # year < 1900: strptime will raise an Exception use naive dates; by
-            # default
-            field = fields.DateTimeField().bind(Form(), 'dt')
-            field.process_formdata(['17/06/1789 | 10:42'])
+        field.populate_obj(obj, 'dt')
+        assert obj.dt == expected_datetime
 
-            # UTC stored
-            assert field.data.tzinfo is pytz.UTC
-            expected_datetime = datetime.datetime(
-                1789,
-                6,
-                17,
-                10,
-                42,
-                tzinfo=pytz.UTC,
-            )
-            assert field.data == expected_datetime
+        # test more recent date: offset is GMT+8
+        field.process_formdata(['23/01/2011 | 10:42'])
+        expected_datetime = datetime.datetime(
+            2011,
+            1,
+            23,
+            2,
+            42,
+            tzinfo=pytz.utc,
+        )
+        assert field.data == expected_datetime
 
-            # naive stored
-            field.populate_obj(obj, 'dt')
-            assert obj.dt == datetime.datetime(1789, 6, 17, 10, 42)
 
-    def test_datetime_field_force_4digit_year(self):
-        # use 'en': short date pattern is 'M/d/yy'
-        headers = {'Accept-Language': 'en'}
-        with self.app.test_request_context(headers=headers):
-            field = fields.DateTimeField().bind(Form(), 'dt')
-            field.data = datetime.datetime(
-                2011, 1, 23, 10, 42, tzinfo=pytz.utc)
-            assert field._value() == '1/23/2011, 6:42 PM'
+def test_datetime_field_naive(app):
+    """Test fields supports date with year < 1900."""
+    patch_babel(app)
 
-    def test_date_field(self):
-        """Test fields supports date with year < 1900."""
-        headers = {'Accept-Language': 'fr-FR,fr;q=0.8'}
-        with self.app.test_request_context(headers=headers):
-            field = fields.DateField().bind(Form(), 'dt')
-            field.process_formdata(['17/06/1789'])
-            assert field.data == datetime.date(1789, 6, 17)
-            assert field._value() == '17/06/1789'
+    obj = mock.Mock()
 
-    def test_datefield_force_4digit_year(self):
-        # use 'en': short date pattern is 'M/d/yy'
-        headers = {'Accept-Language': 'en'}
-        with self.app.test_request_context(headers=headers):
-            field = fields.DateField().bind(Form(), 'dt')
-            field.data = datetime.date(2011, 1, 23)
-            assert field._value() == '1/23/2011'
+    headers = {'Accept-Language': 'fr-FR,fr;q=0.8'}
+    with app.test_request_context(headers=headers):
+        # NAIVE mode: dates without timezone. Those are the problematic ones
+        # when year < 1900: strptime will raise an Exception use naive dates; by
+        # default
+        field = fields.DateTimeField().bind(Form(), 'dt')
+        field.process_formdata(['17/06/1789 | 10:42'])
+
+        # UTC stored
+        assert field.data.tzinfo is pytz.UTC
+        expected_datetime = datetime.datetime(
+            1789,
+            6,
+            17,
+            10,
+            42,
+            tzinfo=pytz.UTC,
+        )
+        assert field.data == expected_datetime
+
+        # naive stored
+        field.populate_obj(obj, 'dt')
+        assert obj.dt == datetime.datetime(1789, 6, 17, 10, 42)
+
+
+def test_datetime_field_force_4digit_year(app):
+    # use 'en': short date pattern is 'M/d/yy'
+    patch_babel(app)
+
+    headers = {'Accept-Language': 'en'}
+    with app.test_request_context(headers=headers):
+        field = fields.DateTimeField().bind(Form(), 'dt')
+        field.data = datetime.datetime(2011, 1, 23, 10, 42, tzinfo=pytz.utc)
+        assert field._value() == '1/23/2011, 6:42 PM'
+
+
+def test_date_field(app):
+    """Test fields supports date with year < 1900."""
+    patch_babel(app)
+
+    headers = {'Accept-Language': 'fr-FR,fr;q=0.8'}
+    with app.test_request_context(headers=headers):
+        field = fields.DateField().bind(Form(), 'dt')
+        field.process_formdata(['17/06/1789'])
+        assert field.data == datetime.date(1789, 6, 17)
+        assert field._value() == '17/06/1789'
+
+
+def test_datefield_force_4digit_year(app):
+    patch_babel(app)
+
+    # use 'en': short date pattern is 'M/d/yy'
+    headers = {'Accept-Language': 'en'}
+    with app.test_request_context(headers=headers):
+        field = fields.DateField().bind(Form(), 'dt')
+        field.data = datetime.date(2011, 1, 23)
+        assert field._value() == '1/23/2011'
