@@ -25,9 +25,11 @@ from flask_wtf.file import FileField
 from six import string_types, text_type
 from six.moves import filter
 from six.moves.urllib import parse
+from wtforms.widgets import HTMLString, Input
 from wtforms.widgets import PasswordInput as BasePasswordInput
+from wtforms.widgets import Select
 from wtforms.widgets import TextArea as BaseTextArea
-from wtforms.widgets import HTMLString, Input, Select, html_params
+from wtforms.widgets import html_params
 from wtforms_alchemy import ModelFieldList
 
 from abilian.core.entities import Entity
@@ -35,7 +37,7 @@ from abilian.core.models.blob import Blob
 from abilian.i18n import _, _l
 from abilian.services import image
 from abilian.services.image import get_format
-from abilian.web import csrf, url_for
+from abilian.web import url_for
 from abilian.web.filters import babel2datepicker, labelize
 
 from .util import babel2datetime
@@ -488,10 +490,12 @@ class SingleView(object):
                     continue
 
                 value = field.data
-                if not isinstance(
+                if (
+                    not isinstance(
                         field,
                         FileField,
-                ) and not field.flags.render_empty:
+                    ) and not field.flags.render_empty
+                ):
                     if value in _to_skip:
                         continue
 
@@ -522,7 +526,6 @@ class SingleView(object):
         ctx = {
             'view': self,
             'related_views': related_views,
-            'csrf_token': csrf.field(),
             'entity': item,
             'panels': panels,
             'form': form,
@@ -1152,15 +1155,17 @@ class DateTimeInput(object):
                 date_value = ''
                 time_value = ''
 
-        return Markup('<div class="form-inline">\n'
-                      '<input class="datetimepicker" type="hidden" id="{id}" name="{name}" '
-                      'value="{date} | {time}" />\n'
-                      ''.format(
-                          id=field_id,
-                          name=field_name,
-                          date=date_value,
-                          time=time_value,
-                      )) \
+        return Markup(
+            '<div class="form-inline">\n'
+            '<input class="datetimepicker" type="hidden" id="{id}" '
+            'name="{name}" value="{date} | {time}" />\n'
+            ''.format(
+                id=field_id,
+                name=field_name,
+                date=date_value,
+                time=time_value,
+            ),
+        ) \
             + self.date(
             field,
             id=field_id + '-date',
