@@ -217,10 +217,8 @@ EDIT_ACTION = Action(
     button='default',
     condition=lambda ctx: ctx['view'].can_edit,
     icon=FAIcon('edit'),
-    url=lambda ctx: url_for(
-        '.entity_edit',
-        **{ctx['view'].pk: ctx['view'].obj.id}
-    ),
+    url=lambda ctx: url_for('.entity_edit',
+                            **{ctx['view'].pk: ctx['view'].obj.id}),
 )
 
 DELETE_ACTION = Action(
