@@ -6,7 +6,6 @@ from __future__ import absolute_import, division, print_function, \
 import imghdr
 from io import BytesIO
 
-import babel
 import babel.dates
 import PIL.Image
 from flask import current_app, flash, g, redirect, render_template, request, \
@@ -15,6 +14,7 @@ from werkzeug.exceptions import InternalServerError
 from wtforms.fields import StringField
 from wtforms.validators import ValidationError
 
+from abilian.core.extensions import db
 from abilian.i18n import _, _l, get_default_locale
 from abilian.services.preferences.panel import PreferencePanel
 from abilian.web import csrf
@@ -56,8 +56,8 @@ class UserPreferencesForm(Form):
         if pwd != confirmed:
             raise ValidationError(
                 _(
-                    'Passwords differ. Ensure you have typed same password in both'
-                    ' "password" field and "confirm password" field.',
+                    'Passwords differ. Ensure you have typed same password '
+                    'in both "password" field and "confirm password" field.',
                 ),
             )
 
@@ -130,11 +130,9 @@ class UserPreferencesPanel(PreferencePanel):
         )
         if form['locale'].data is None:
             form['locale'].data = get_default_locale()
-        return render_template(
-            'preferences/user.html',
-            form=form,
-            title=self.label,
-        )
+
+        ctx = {'form': form, 'title': self.label}
+        return render_template('preferences/user.html', **ctx)
 
     @csrf.support_graceful_failure
     def post(self):
@@ -162,7 +160,7 @@ class UserPreferencesPanel(PreferencePanel):
 
             form.populate_obj(g.user)
 
-            current_app.db.session.commit()
+            db.session.commit()
             flash(_("Preferences saved."), "info")
             return redirect(url_for(".user"))
         else:
