@@ -1,13 +1,9 @@
-/* jshint unused: false */
-(function(factory) {
-  "use strict";
-
-  define(
-    "widget.FileInput",
-    ["AbilianWidget", "jquery", "FileAPI", "Hogan"],
-    factory
-  );
-})(function(Abilian, $, api, Hogan) {
+define("widget.FileInput", [
+  "AbilianWidget",
+  "jquery",
+  "FileAPI",
+  "Hogan",
+], function(Abilian, $, api, Hogan) {
   "use strict";
   /**
    * File input widget. Uses FileAPI (http://mailru.github.io/FileAPI/)
