@@ -1,24 +1,24 @@
 # coding=utf-8
 """"""
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 
 import logging
-import os
 import socket
 from collections import OrderedDict, namedtuple
-from pathlib import Path
 
 import redis
 import six
 import sqlalchemy as sa
 import sqlalchemy.dialects
 import sqlalchemy.exc
-from flask import current_app, flash, make_response, redirect, \
+from flask import current_app, flash, redirect, \
     render_template, request, session, url_for
+from pathlib import Path
 from six import text_type
 
 from abilian.core.commands import config as cmd_config
-from abilian.core.extensions import csrf
+from abilian.core.extensions import csrf, db
 from abilian.core.models.subjects import User
 from abilian.services import get_service
 from abilian.services.security import Admin, Anonymous
@@ -36,8 +36,8 @@ setup = Blueprint(
 # module ('psycopg2' missing for example)
 
 _dialects = OrderedDict((
-    ('sqlite', u'SQLite (for demo)'),
-    ('postgres', u'PostgreSQL'),
+    ('sqlite', 'SQLite (for demo)'),
+    ('postgresql', 'PostgreSQL'),
 ))
 
 _dialects_unavailable = OrderedDict()
@@ -61,7 +61,7 @@ _setup_steps = (
         'Basic site informations',
         'Site name, admin email...',
     ),
-    Step('admin_account', 'step_admin_account', u'Admin account', None),
+    Step('admin_account', 'step_admin_account', 'Admin account', None),
     Step('finalize', 'finalize', 'Finalize', None),
 )
 
@@ -96,7 +96,6 @@ def common_context():
         'dialects_unavailable': _dialects_unavailable,
         'validated_steps': session_get('validated', ()),
     }
-
     ctx.update(request.setup_step_progress)
     return ctx
 
@@ -147,49 +146,49 @@ def step_db_form():
 def step_db_validate():
     form = request.form
     dialect = form['dialect']
-    username = form.get(u'username', u'').strip()
-    password = form.get(u'password', u'').strip()
-    host = form.get(u'host', u'').strip()
-    port = form.get(u'port', u'').strip()
-    database = form.get(u'database', u'').strip()
+    username = form.get('username', '').strip()
+    password = form.get('password', '').strip()
+    host = form.get('host', '').strip()
+    port = form.get('port', '').strip()
+    database = form.get('database', '').strip()
 
     # build db_uri
-    db_uri = u'{}://'.format(dialect)
+    db_uri = '{}://'.format(dialect)
 
-    if dialect != u'sqlite':
+    if dialect != 'sqlite':
         if username:
             db_uri += username
             # check password only if we have a username
             if password:
-                db_uri += u':' + password
+                db_uri += ':' + password
 
-        # FIXME: it is an error to have a username and no host, SA will interpret
-        # username:password as host:port
+        # FIXME: it is an error to have a username and no host,
+        # SA will interpret username:password as host:port
         if host:
-            db_uri += u'@' + host
+            db_uri += '@' + host
             port = port
             if port:
-                db_uri += u':' + port
+                db_uri += ':' + port
 
-    db_uri += u'/'
+    db_uri += '/'
 
-    if dialect == u'sqlite' and (not database or database == u':memory:'):
+    if dialect == 'sqlite' and (not database or database == ':memory:'):
         database = text_type(
-            Path(current_app.instance_path) / u'data' / u'sqlite.db',
+            Path(current_app.instance_path) / 'data' / 'sqlite.db',
         )
 
     db_uri += database
 
     # store in session
-    db_params = dict(
-        uri=db_uri,
-        dialect=dialect,
-        username=username,
-        password=password,
-        host=host,
-        port=port,
-        database=database,
-    )
+    db_params = {
+        'uri': db_uri,
+        'dialect': dialect,
+        'username': username,
+        'password': password,
+        'host': host,
+        'port': port,
+        'database': database,
+    }
     session_set('db', db_params)
 
     # test connection
@@ -214,7 +213,8 @@ def step_db_validate():
 
     step_validated('db')
     next_step = request.setup_step_progress['next_step']
-    return redirect(url_for('{}.{}'.format(setup.name, next_step.endpoint)))
+    endpoint = '{}.{}'.format(setup.name, next_step.endpoint)
+    return redirect(url_for(endpoint))
 
 
 #
@@ -238,9 +238,9 @@ def step_redis_form():
 def step_redis_validate():
     form = request.form
     data = dict(
-        host=form.get(u'host', u'localhost').strip(),
-        port=form.get(u'port', u'').strip() or u'6379',
-        db=form.get(u'db', u'').strip() or u'1',
+        host=form.get('host', 'localhost').strip(),
+        port=form.get('port', '').strip() or '6379',
+        db=form.get('db', '').strip() or '1',
     )
 
     for k in ('port', 'db'):
@@ -249,7 +249,7 @@ def step_redis_validate():
         except ValueError:
             pass
 
-    data['uri'] = u'redis://{host}:{port}/{db}'.format(**data)
+    data['uri'] = 'redis://{host}:{port}/{db}'.format(**data)
     session_set('redis', data)
     error = None
 
@@ -260,20 +260,20 @@ def step_redis_validate():
             db=data['db'],
         )
     except Exception as e:
-        error = u'Connection error, check parameters'
+        error = 'Connection error, check parameters'
         raise e
 
     try:
         r.info()
     except redis.exceptions.InvalidResponse:
         error = (
-            u"Connection error: doesn't look like it's a redis server. "
-            u"Verify host and port are those of your redis server."
+            "Connection error: doesn't look like it's a redis server. "
+            "Verify host and port are those of your redis server."
         )
     except redis.exceptions.ResponseError as e:
-        error = u'Redis server response: {}'.format(e)
+        error = 'Redis server response: {}'.format(e)
     except redis.exceptions.RedisError as e:
-        error = u'Unknown redis error ({})'.format(e)
+        error = 'Unknown redis error ({})'.format(e)
 
     if error:
         flash(error, 'error')
@@ -281,7 +281,8 @@ def step_redis_validate():
 
     step_validated('redis')
     next_step = request.setup_step_progress['next_step']
-    return redirect(url_for('{}.{}'.format(setup.name, next_step.endpoint)))
+    endpoint = '{}.{}'.format(setup.name, next_step.endpoint)
+    return redirect(url_for(endpoint))
 
 
 #
@@ -310,7 +311,7 @@ def get_possible_hostnames():
             names.setdefault(a, []).extend(ips)
 
     return sorted(
-        u'{} ({})'.format(name, u', '.join(sorted(set(ips))))
+        '{} ({})'.format(name, ', '.join(sorted(set(ips))))
         for name, ips in six.iteritems(names)
     )
 
@@ -318,8 +319,8 @@ def get_possible_hostnames():
 def step_site_info_form():
     cfg = current_app.config
     default_data = {
-        'sitename': cfg.get('SITE_NAME', u'') or u'',
-        'mailsender': cfg.get('MAIL_SENDER', u'') or u'',
+        'sitename': cfg.get('SITE_NAME', '') or '',
+        'mailsender': cfg.get('MAIL_SENDER', '') or '',
     }
     return render_template(
         'setupwizard/step_site_info.html',
@@ -330,16 +331,17 @@ def step_site_info_form():
 
 def step_site_info_validate():
     form = request.form
-    data = dict(
-        sitename=form.get('sitename', u'').strip(),
-        mailsender=form.get('mailsender', u'').strip(),
-        server_mode=form.get('server_mode', u'').strip(),
-    )
+    data = {
+        'sitename': form.get('sitename', '').strip(),
+        'mailsender': form.get('mailsender', '').strip(),
+        'server_mode': form.get('server_mode', '').strip(),
+    }
 
     session_set('site_info', data)
     step_validated('site_info')
     next_step = request.setup_step_progress['next_step']
-    return redirect(url_for('{}.{}'.format(setup.name, next_step.endpoint)))
+    endpoint = '{}.{}'.format(setup.name, next_step.endpoint)
+    return redirect(url_for(endpoint))
 
 
 #
@@ -362,15 +364,15 @@ def step_admin_account_form():
 
 def step_admin_account_validate():
     form = request.form
-    password = form.get('password', u'').strip()
-    confirm_password = form.get('confirm_password', u'').strip()
-    admin_user = dict(
-        email=form.get('email', u'').strip(),
-        name=form.get('name', u'').strip(),
-        firstname=form.get('firstname', u'').strip(),
-        password=password,
-        confirm_password=confirm_password,
-    )
+    password = form.get('password', '').strip()
+    confirm_password = form.get('confirm_password', '').strip()
+    admin_user = {
+        'email': form.get('email', '').strip(),
+        'name': form.get('name', '').strip(),
+        'firstname': form.get('firstname', '').strip(),
+        'password': password,
+        'confirm_password': confirm_password,
+    }
     session_set('admin_account', admin_user)
 
     if password != confirm_password:
@@ -379,7 +381,8 @@ def step_admin_account_validate():
 
     step_validated('admin_account')
     next_step = request.setup_step_progress['next_step']
-    return redirect(url_for('{}.{}'.format(setup.name, next_step.endpoint)))
+    endpoint = '{}.{}'.format(setup.name, next_step.endpoint)
+    return redirect(url_for(endpoint))
 
 
 #
@@ -397,7 +400,7 @@ def finalize():
 
 
 def finalize_form():
-    file_location = os.path.join(current_app.instance_path, 'config.py')
+    file_location = Path(current_app.instance_path) / 'config.py'
     return render_template(
         'setupwizard/finalize.html',
         file_location=file_location,
@@ -405,10 +408,10 @@ def finalize_form():
 
 
 def finalize_validate():
-    config_file = os.path.join(current_app.instance_path, 'config.py')
-    logging_file = os.path.join(current_app.instance_path, 'logging.yml')
+    config_file = Path(current_app.instance_path) / 'config.py'
+    logging_file = Path(current_app.instance_path) / 'logging.yml'
 
-    assert not os.path.exists(config_file)
+    assert not config_file.exists()
     config = cmd_config.DefaultConfig(logging_file='logging.yml')
     config.SQLALCHEMY_DATABASE_URI = session_get('db')['uri']
 
@@ -421,7 +424,7 @@ def finalize_validate():
     config.SITE_NAME = d['sitename']
     config.MAIL_SENDER = d['mailsender']
 
-    is_production = d['server_mode'] == u'production'
+    is_production = d['server_mode'] == 'production'
     config.PRODUCTION = is_production
     config.DEBUG = not is_production
     config.DEBUG_TB_ENABLED = config.DEBUG
@@ -431,8 +434,8 @@ def finalize_validate():
     cmd_config.maybe_write_logging(logging_file)
 
     admin_account = session_get('admin_account')
-    # create a new app that will be configured with new config, to create database
-    # and admin_user
+    # create a new app that will be configured with new config,
+    # to create database and admin_user
     setup_app = current_app._get_current_object()
     app = setup_app.__class__(
         setup_app.import_name,
@@ -443,7 +446,7 @@ def finalize_validate():
     )
     with app.test_request_context('/setup/finalize'):
         app.create_db()
-        db_session = app.db.session()
+        db_session = db.session()
         admin = User(
             email=admin_account['email'],
             password=admin_account['password'],
@@ -458,12 +461,8 @@ def finalize_validate():
 
     session_clear()
 
-    response = make_response(
-        render_template(
-            'setupwizard/done.html',
-            config_file=config_file,
-            logging_file=logging_file,
-        ),
-        200,
+    return render_template(
+        'setupwizard/done.html',
+        config_file=config_file,
+        logging_file=logging_file,
     )
-    return response
