@@ -43,8 +43,7 @@ class TagCriterion(BaseCriterion):
         return Tag.query.filter(
             Tag.ns == self.ns,
             Tag.id.in_(model_tags),
-        )\
-            .all()
+        ).all()
 
     def get_request_values(self, request):
         tag_ids = []
