@@ -4,7 +4,7 @@ from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import sys
-from typing import List
+from typing import List, Text
 
 from blinker import Namespace, Signal
 from flask import current_app, g
@@ -30,6 +30,7 @@ class ActionDebugPanel(DebugPanel):
         return ''
 
     def content(self):
+        # type: () -> Text
         actions_for_template = []
 
         for category in actions.actions().keys():
@@ -80,6 +81,7 @@ class SignalsDebugPanel(DebugPanel):
         return ''
 
     def content(self):
+        # type: () -> Text
         module_names = sorted(sys.modules.keys())
 
         signals = []
@@ -96,17 +98,15 @@ class SignalsDebugPanel(DebugPanel):
                 ns = var
                 ns_name = var_name
                 for signal_name, signal in ns.items():
+                    receivers = [
+                        text_type(r) for r in signal.receivers.values()
+                    ]
                     d = {
-                        'module_name':
-                        module_name,
-                        'ns_name':
-                        ns_name,
-                        'signal_name':
-                        signal_name,
-                        'signal':
-                        signal,
-                        'receivers':
-                        [text_type(r) for r in signal.receivers.values()],
+                        'module_name': module_name,
+                        'ns_name': ns_name,
+                        'signal_name': signal_name,
+                        'signal': signal,
+                        'receivers': receivers,
                     }
                     signals.append(d)
 
