@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -33,8 +32,7 @@ class BaseUploadsView(object):
 
 
 class NewUploadView(BaseUploadsView, JSONView):
-    """Upload a new file.
-    """
+    """Upload a new file."""
     methods = ['POST', 'PUT']
     decorators = (csrf.support_graceful_failure,)
 
@@ -44,8 +42,7 @@ class NewUploadView(BaseUploadsView, JSONView):
     def data(self, *args, **kwargs):
         return {
             'handle': self.handle,
-            'url': url_for(
-                '.handle', handle=self.handle),
+            'url': url_for('.handle', handle=self.handle),
         }
 
     def post(self, *args, **kwargs):
@@ -58,7 +55,11 @@ class NewUploadView(BaseUploadsView, JSONView):
         filename = secure_filename(uploaded.filename)
         mimetype = uploaded.mimetype
         self.handle = self.uploads.add_file(
-            self.user, uploaded, filename=filename, mimetype=mimetype)
+            self.user,
+            uploaded,
+            filename=filename,
+            mimetype=mimetype,
+        )
         return self.get(*args, **kwargs)
 
     def put(self, *args, **kwargs):
@@ -69,8 +70,7 @@ bp.add_url_rule('/', view_func=NewUploadView.as_view('new_file'))
 
 
 class UploadView(BaseUploadsView, View):
-    """Manage an uploaded file: download, delete.
-    """
+    """Manage an uploaded file: download, delete."""
     methods = ['GET', 'DELETE']
     decorators = (csrf.support_graceful_failure,)
 
@@ -92,7 +92,8 @@ class UploadView(BaseUploadsView, View):
             mimetype=content_type,
             cache_timeout=0,
             add_etags=False,
-            conditional=False)
+            conditional=False,
+        )
 
     def delete(self, handle, *args, **kwargs):
         if self.uploads.get_file(self.user, handle) is None:
