@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -45,30 +44,30 @@ class View(BaseView):
             return exc.response
 
     def prepare_args(self, args, kwargs):
-        """
-        If view arguments need to be prepared it can be done here.
+        """If view arguments need to be prepared it can be done here.
 
-        A typical use case is to take an identifier, convert it to an object
-        instance and maybe store it on view instance and/or replace
-        identifier by object in arguments.
+        A typical use case is to take an identifier, convert it to an
+        object instance and maybe store it on view instance and/or
+        replace identifier by object in arguments.
         """
         return args, kwargs
 
     def redirect(self, url):
-        """
-        Shortcut all call stack and return response.
+        """Shortcut all call stack and return response.
 
         usage: `self.response(url_for(...))`
         """
         raise Redirect(response=redirect(url))
 
 
-_JSON_HTML = u'''
+_JSON_HTML = '''
 <!DOCTYPE html>
 <html lang="en">
 <head>
   <meta charset="utf-8">
-  <link rel="stylesheet" href="{{ url_for('abilian_static', filename="highlightjs/default.min.css") }}" />
+  <title>JSON preview</title>
+  <link rel="stylesheet"
+    href="{{ url_for('abilian_static', filename="highlightjs/default.min.css") }}" />
 </head>
 <body>
   <pre>
@@ -87,8 +86,8 @@ _JSON_HTML = u'''
 class JSONView(View):
     """Base view for JSON GET.
 
-    Renders as JSON when requested by Ajax, renders as HTML when requested
-    from browser.
+    Renders as JSON when requested by Ajax, renders as HTML when
+    requested from browser.
     """
 
     def prepare_args(self, args, kwargs):
@@ -96,17 +95,18 @@ class JSONView(View):
         return args, kwargs
 
     def data(self, *args, **kwargs):
-        """This method should return data to be serialized using JSON
-        """
+        """This method should return data to be serialized using JSON."""
         raise NotImplementedError
 
     def get(self, *args, **kwargs):
         data = self.data(*args, **kwargs)
         best_mime = request.accept_mimetypes.best_match(
-            ['text/html', 'application/json'])
+            ['text/html', 'application/json'],
+        )
         if best_mime == 'application/json':
             return jsonify(data)
 
-        # dev requesting from browser? serve html, let debugtoolbar show up, etc...
+        # dev requesting from browser? serve html, let debugtoolbar show up,
+        # etc...
         content = json.dumps(data, indent=2)
         return render_template_string(_JSON_HTML, content=content)
